Lua_MarryInfoShowPanel = class("Lua_MarryInfoShowPanel", Lua_DisplayObject);
function Lua_MarryInfoShowPanel:ctor(p)
	self:superCall("ctor", p, "MarryInfoShowPanel_skin");
end

function Lua_MarryInfoShowPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.titleImg:setEnable(false);

	self.titleBtn:addClickFuntion(self, self.onTitleBtnClick);
	self.breakBtn:addClickFuntion(self, self.onBreakBtnClick);

	self:onUpdateMarryInfo();
	self:addLuaEvent("rMarryInfo", self, self.onUpdateMarryInfo);
end

-- 更新面板信息
function Lua_MarryInfoShowPanel:onUpdateMarryInfo()
	local marryNewData = DataCenter.marryNewData;
	self.bMarried = marryNewData.bMarried;
	self.closeNum.text = LanUtil.formateStr(LanUtil.getValue(144007), tostring(marryNewData.intimacy));

	local labelId = marryNewData.labelId;
	if labelId ~= nil and labelId ~= 0 then
		local titleData = Lua_TitleData.new(labelId);
		self.titleImg:setAltas(tostring(titleData.atlas), tostring(labelId));
		self.titleImg:resetSize();
		self.titleImg:setEnable(true);
	end

	local keepsakeInfo = marryNewData.keepsakeInfo;
	if keepsakeInfo ~= nil and keepsakeInfo.keepsake_id > 0 then
		local vo = Lua_ToolVo.new(keepsakeInfo.keepsake_id);
		local keepsakeLv = keepsakeInfo.keepsake_lvl;
		local gradeNum = math.floor(keepsakeLv / 10) + 1;
		local classNum = (keepsakeLv % 10) + 1;
		self.lockNum.text = LanUtil.formateStr(LanUtil.getValue(144008), vo.colorName, tostring(gradeNum), tostring(classNum));
	else
		self.lockNum.text = "";
	end

	if marryNewData.weddingTime ~= nil then
		local leftTime = tonumber(tostring(marryNewData.weddingTime));
		self.marryDateTxt.text = LanUtil.formateStr(LanUtil.getValue(144009), TimeTransform.getInstance():transSeconds8(leftTime, "yyyy-MM-dd"));
		
		leftTime = tonumber(tostring(GlobalVar.cur_tick)) - tonumber(tostring(marryNewData.weddingTime));
		self.marryDayTxt.text = LanUtil.formateStr(LanUtil.getValue(144010), TimeTransform.getInstance():transTimeLeft(leftTime));
	end
	
	-- 自己
	self.leftName.text = DataCenter.roleData.name;
	if DataCenter.roleData.sex == Lua_ThingDefine.MALE then -- 男
		self.leftGenderImg:setAltas("yinyuan_altas", "ui_marriage_man");
	else
		self.leftGenderImg:setAltas("yinyuan_altas", "ui_marriage_woman");
	end
	self.leftGenderImg:resetSize();

	local box = marryNewData.ownBoxInfo;
	if box == nil or box.buy_tick == 0 then
		self.leftBoxTxt.text = LanUtil.getValue(144005);
	else
		leftTime = tonumber(tostring(box.left_time)) - tonumber(tostring(GlobalVar.cur_tick));
		if leftTime > 0 then
			self.leftBoxTxt.text = LanUtil.formateStr(LanUtil.getValue(144006), TimeTransform.getInstance():transTimeLeft(leftTime));
		else
			self.leftBoxTxt.text = LanUtil.getValue(144005);
		end
	end

	-- 配偶
	if self.bMarried == false then
		self.rightName.text = "";
		self.rightBoxTxt.text = LanUtil.getValue(144005);
	else
		local spouseInfo = marryNewData.spouseInfo;
		self.rightName.text = spouseInfo.role_name;
		if spouseInfo.sex == Lua_ThingDefine.MALE then -- 男
			self.rightGenderImg:setAltas("yinyuan_altas", "ui_marriage_man");
		else
			self.rightGenderImg:setAltas("yinyuan_altas", "ui_marriage_woman");
		end
		self.rightGenderImg:resetSize();

		box = marryNewData.otherBoxInfo;
		if box == nil or box.buy_tick == 0 then
			self.rightBoxTxt.text = LanUtil.getValue(144005);
		else
			leftTime = tonumber(tostring(box.left_time)) - tonumber(tostring(GlobalVar.cur_tick));
			if leftTime > 0 then
				self.rightBoxTxt.text = LanUtil.formateStr(LanUtil.getValue(144006), TimeTransform.getInstance():transTimeLeft(leftTime));
			else
				self.rightBoxTxt.text = LanUtil.getValue(144005);
			end
		end
	end

	self:updateSelfModel();
	self:updateSpouseModel();
end

-- 更新玩家自身模型
function Lua_MarryInfoShowPanel:updateSelfModel()
	local rd = DataCenter.roleData;
	local modelData = UsData();
	modelData.roleId = rd.roleId;
	modelData.career = rd.career;
	modelData.gender = rd.sex;
	modelData.weapon_id = rd.weapon_id;
	modelData.clothes_id = rd.clothes_id;
	modelData.wingId = rd.wingId;
	modelData.fashion_weapon_id = rd.fashion_weapon_id;
	modelData.fashion_clothes_id = rd.fashion_clothes_id;
	modelData.fashionHeadId = rd.fashionHeadId;
	modelData.nickname = "";
	modelData.hp = 1;
	modelData.kind = 1;
	modelData.isShowName = false;
	modelData.IsUI = true;

	if self.leftPlayerModel == nil then
		self.leftPlayerModel = ModelPlayer();
	end
	self.leftPlayerModel:init(self.content, Vector3(-385, -140, 0), Vector3(0, 90, 0), modelData, nil, 200);
	self.leftPlayerModel:setRotEnable(true, 0, 200, 250, 400, 2);
	self.leftPlayerModel:SetRenderQueue(self.leftNameBg, 0, 1);
end

-- 更新配偶模型
function Lua_MarryInfoShowPanel:updateSpouseModel()
	if self.bMarried == false then
		if self.rightPlayerModel ~= nil then
			self.rightPlayerModel:dispose();
			self.rightPlayerModel = nil;
		end
		return;
	end

	local rd = DataCenter.marryNewData;
	local modelData = UsData();
	modelData.roleId = rd.spouseInfo.role_id;
	modelData.career = rd.spouseInfo.career;
	modelData.gender = rd.spouseInfo.sex;
	modelData.weapon_id = rd.weapon;
	modelData.clothes_id = rd.fashion;
	modelData.wingId = rd.wingId;
	modelData.fashion_weapon_id = rd.fashion_weapon_id;
	modelData.fashion_clothes_id = rd.fashion_clothes_id;
	modelData.fashionHeadId = rd.fashion_headgear_id;
	modelData.nickname = "";
	modelData.hp = 1;
	modelData.kind = 1;
	modelData.isShowName = false;
	modelData.IsUI = true;

	if self.rightPlayerModel == nil then
		self.rightPlayerModel = ModelPlayer();
	end
	self.rightPlayerModel:init(self.content, Vector3(265, -140, 0), Vector3(0, 90, 0), modelData, nil, 200);
	self.rightPlayerModel:setRotEnable(true, 0, 200, 250, 400, 2);
	self.rightPlayerModel:SetRenderQueue(self.rightNameBg, 0, 1); 
end

-- 姻缘称号
function Lua_MarryInfoShowPanel:onTitleBtnClick(go)
	Lua_WindowUtil.openWin("Lua_MarryTitleShowWindow", WinParam.ACTION_OPEN, nil);
end

-- 离婚
function Lua_MarryInfoShowPanel:onBreakBtnClick(go)
	if self.bMarried == nil or self.bMarried ~= true then
		OperateAlert.show(LanUtil.getValue(144015));
		return;
	end

	Lua_WindowUtil.openWin("Lua_MarryNewMainWindow", WinParam.ACTION_CLOSE);
	Lua_ProxyManager.getProxy("Lua_MapProxy"):sTransfer(10103, 18366, 1975, 9383, 0);
	Lua_WindowUtil.openWin("Lua_MarryWindow", WinParam.ACTION_OPEN);
end

function Lua_MarryInfoShowPanel:dispose()
	if self.rightPlayerModel ~= nil then
		self.rightPlayerModel:dispose();
		self.rightPlayerModel = nil;
	end
	if self.leftPlayerModel ~= nil then
		self.leftPlayerModel:dispose();
		self.leftPlayerModel = nil;
	end

	self:superCall("dispose");
end