Lua_MarryKeepsakeInfoPanel = class("Lua_MarryKeepsakeInfoPanel", Lua_DisplayObject);
function Lua_MarryKeepsakeInfoPanel:ctor(p)
	self:superCall("ctor", p, "MarryKeepsakeInfoPanel_skin", true);
end

function Lua_MarryKeepsakeInfoPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.descTxt.text = LanUtil.getValue(144057);
	self.autoUpgradeBtn.label = LanUtil.getValue(144060);

	self.uRedDot1:setEnable(false);
	self.uRedDot2:setEnable(false);

	self.keepsakeIcon = Lua_ToolImage.new(self.content);
	self.keepsakeIcon:setDepth(6);
	self.keepsakeIcon:setLocation(-309, 35, 0);

	self.fightNum = Lua_NumberImage.new(self.content);
	self.fightNum.numWidth = 13;
	self.fightNum.numAtlas = "number_atlas";
	self.fightNum:setDepth(6);
	self.fightNum:setLocation(287, 236, 0);

	self.attrsList = Lua_DragList.new(self.content, 1, Vector4(0, 0, 400, 150));
	self.attrsList:setLocation(272, 90, 0);
	self.attrsList:setListCell(Lua_MarryAttrsItem, 30, 20, 1);

	self.costList = Lua_DragList.new(self.content, 2, Vector4(0, 0, 160, 80));
	self.costList:setLocation(272, -95, 0);
	self.costList:setListCell(Lua_MarryKeepsakeCostItem, 80, 80, 5);

	self.bAutoUpgrade = false;

	self:updateKeepsakeInfo();
	self:updateKeepsakeSkill();
	self:onUpdateRedDot();

	self.reissueBtn:addClickFuntion(self, self.onReissueBtnClick);
	self.autoUpgradeBtn:addClickFuntion(self, self.onAutoUpgradeBtnClick);
	self.upgradeBtn:addClickFuntion(self, self.onUpgradeBtnClick);

	self:addLuaEvent("rUpdateKeepsakeInfo", self, self.onUpdateInfoHandler);
	self:addLuaEvent("rMarryKeepsakeUpgrade", self, self.onUpgradeHandler);
	self:addLuaEvent("rMarryInfo", self, self.onUpdateInfoHandler);
	self:addLuaEvent("PACK_UPDATE", self, self.onPackDataUpdate);
end

function Lua_MarryKeepsakeInfoPanel:updateKeepsakeInfo()
	local keepsakeInfo = DataCenter.marryNewData.keepsakeInfo;
	if keepsakeInfo ~= nil then
		local showItemId = keepsakeInfo.keepsake_id;
		if showItemId <= 0 then
			showItemId = DataCenter.marryNewUtil.defautShowKeepsakeId;
		end
		self.keepsakeIcon.data = Lua_ToolVo.new(showItemId);
		self.keepsakeName.text = LanUtil.formateStr(LanUtil.getValue(144104), self.keepsakeIcon.data.name, tostring(keepsakeInfo.keepsake_lvl % 10));

		local flower
		for i = 1, 10 do -- 十级一阶
			flower = self["flower"..i];
			if flower ~= nil then
				if i > num then -- 置灰
					flower:setGray(true);
				else
					flower:setGray(false);
				end
			end
		end

		local strArr = string.split(LanUtil.getValue(110507), ",");
		local str = string.split(LanUtil.getValue(110508), ",")[1];
		num = math.floor(keepsakeInfo.keepsake_lvl / 10);
		self.gradeTxt.text = strArr[num + 2]..str;

		local curVo = DataCenter.marryNewUtil:getKeepsakeInfoVo(showItemId, keepsakeInfo.keepsake_lvl);
		local nextVo = DataCenter.marryNewUtil:getKeepsakeInfoVo(showItemId, keepsakeInfo.keepsake_lvl + 1);
		if curVo ~= nil then
			if nextVo ~= nil then
				self.expBar:setText(keepsakeInfo.keepsake_exp.."/"..nextVo.need_exp);
				self.expBar:setMaxValue(nextVo.need_exp);
				self.expBar:setValue(keepsakeInfo.keepsake_exp);
				if keepsakeInfo.keepsake_id <= 0 then
					self.autoUpgradeBtn:setGray(true);
					self.upgradeBtn:setGray(true);
				else
					self.autoUpgradeBtn:setGray(false);
					self.upgradeBtn:setGray(false);
				end
			else
				self.expBar:setText(LanUtil.getValue(144092));
				self.expBar:setMaxValue(1);
				self.expBar:setValue(1);
				self.autoUpgradeBtn:setGray(true);
				self.upgradeBtn:setGray(true);
			end

			-- 消耗
			self:updateCost(curVo.costArr);
		end

		if keepsakeInfo.keepsake_id <= 0 then
			self:updateAttrs(nil, curVo);
		else
			self:updateAttrs(curVo, nextVo);
		end
	end
end

-- 更新消耗
function Lua_MarryKeepsakeInfoPanel:updateCost(costArr)
	if costArr == nil then
		local keepsakeInfo = DataCenter.marryNewData.keepsakeInfo;
		if keepsakeInfo == nil then
			return;
		end

		local showItemId = keepsakeInfo.keepsake_id;
		if showItemId <= 0 then
			showItemId = DataCenter.marryNewUtil.defautShowKeepsakeId;
		end

		local curVo = DataCenter.marryNewUtil:getKeepsakeInfoVo(showItemId, keepsakeInfo.keepsake_lvl);
		if curVo == nil then
			return;
		end
		costArr = curVo.costArr;
		self:onUpdateRedDot(curVo);
	end

	if costArr == nil then
		return;
	end

	local len = costArr:getSize();
	self.costList.canDrag = len > 2;
	self.costList:setLuaArrayData(costArr, false);
	self.costList:setLocation(272 + len * 80 / 2, -95, 0);
end

-- 展示属性
function Lua_MarryKeepsakeInfoPanel:updateAttrs(curVo, nextVo)
	if curVo == nil and nextVo == nil then
		return;
	end

	local list;
	local arr = Array();
	if nextVo == nil then -- 等阶最大了
		list = curVo.attrsArr;
		for i = 1, list:getSize() do
			arr:add({name = list[i].name, curValue = list[i].value, nextValue = 0});
		end
	else -- 有下一阶
		if curVo ~= nil then
			list = curVo.attrsArr;
			local num;
			for i = 1, list:getSize() do
				num = nextVo.attrsDic[list[i].name];
				num = num ~= nil and num - list[i].value or 0;
				arr:add({name = list[i].name, curValue = list[i].value, nextValue = num});
			end

			-- 防止下一阶有，而当前阶没有情况
			list = nextVo.attrsArr;
			for i = 1, list:getSize() do
				num = curVo.attrsDic[list[i].name];
				if num == nil then
					arr:add({name = list[i].name, curValue = 0, nextValue = list[i].value});
				end
			end
		else
			list = nextVo.attrsArr;
			for i = 1, list:getSize() do
				arr:add({name = list[i].name, curValue = 0, nextValue = list[i].value});
			end
		end
	end
	self.attrsList:setLuaArrayData(arr, false);
end

-- 战力更新
function Lua_MarryKeepsakeInfoPanel:updateKeepsakeSkill()
	local keepsakeInfo = DataCenter.marryNewData.keepsakeInfo;
	if keepsakeInfo ~= nil and keepsakeInfo.keepsake_id > 0 then
		self.fightNum.num = DataCenter.marryNewData.keepsakeFighting;
	else
		self.fightNum.num = DataCenter.marryNewUtil.defautShowKeepsakeForce;
	end
end

function Lua_MarryKeepsakeInfoPanel:onUpdateRedDot(curVo)
	if curVo == nil then
		local keepsakeInfo = DataCenter.marryNewData.keepsakeInfo;
		curVo = DataCenter.marryNewUtil:getKeepsakeInfoVo(keepsakeInfo.keepsake_id, keepsakeInfo.keepsake_lvl);
	end
	self.uRedDot1:setEnable(curVo ~= nil and curVo:checkUpgrade());
	self.uRedDot2:setEnable(curVo ~= nil and curVo:checkUpgrade());
end

-- 结婚信息变更
function Lua_MarryKeepsakeInfoPanel:onUpdateInfoHandler()
	self:updateKeepsakeInfo();
end

-- 信物更新
function Lua_MarryKeepsakeInfoPanel:onUpgradeHandler(errno)
	if errno == 0 then
		self:updateKeepsakeInfo();
	else -- 暂停自动升级
		if self.bAutoUpgrade == true then
			self:onAutoUpgradeBtnClick();
		end
	end
end

-- 背包更新
function Lua_MarryKeepsakeInfoPanel:onPackDataUpdate(packType)
	if packType == Lua_PackData.BAG_PACK then
		self:updateCost();
	end
end

-- 补办
function Lua_MarryKeepsakeInfoPanel:onReissueBtnClick(go)
	if self.bAutoUpgrade == true then
		self:onAutoUpgradeBtnClick();
	end
	Lua_ProxyManager.getProxy("Lua_MarryNewProxy"):sReissueWedding();
end

-- 自动进阶
function Lua_MarryKeepsakeInfoPanel:onAutoUpgradeBtnClick(go)
	self.bAutoUpgrade = not self.bAutoUpgrade;
	if self.bAutoUpgrade == true then
		Lua_CommonUtil.addTimer("keepsakeAutoUpgradeHandler", 0.1, self, self.keepsakeAutoUpgradeHandler);
		self.autoUpgradeBtn.label = LanUtil.getValue(144061);
	else
		Lua_CommonUtil.removeTimer(self, self.keepsakeAutoUpgradeHandler);
		self.autoUpgradeBtn.label = LanUtil.getValue(144060);
	end
end

function Lua_MarryKeepsakeInfoPanel:keepsakeAutoUpgradeHandler()
	local keepsakeInfo = DataCenter.marryNewData.keepsakeInfo;
	if keepsakeInfo == nil or keepsakeInfo.keepsake_id <= 0 then
		OperateAlert.show(LanUtil.getValue(144058));
		if self.bAutoUpgrade == true then
			self:onAutoUpgradeBtnClick();
		end
		return;
	end

	local curVo = DataCenter.marryNewUtil:getKeepsakeInfoVo(keepsakeInfo.keepsake_id, keepsakeInfo.keepsake_lvl);
	if curVo == nil then
		OperateAlert.show(LanUtil.getValue(144059));
		if self.bAutoUpgrade == true then
			self:onAutoUpgradeBtnClick();
		end
		return;
	end

	if curVo:checkUpgrade(true) == false then
		if self.bAutoUpgrade == true then
			self:onAutoUpgradeBtnClick();
		end
		return;
	end
	Lua_ProxyManager.getProxy("Lua_MarryNewProxy"):sMarryKeepsakeUpgrade();
end

-- 进阶
function Lua_MarryKeepsakeInfoPanel:onUpgradeBtnClick(go)
	if self.bAutoUpgrade == true then
		self:onAutoUpgradeBtnClick();
	end
	self:keepsakeAutoUpgradeHandler();
end

function Lua_MarryKeepsakeInfoPanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.keepsakeAutoUpgradeHandler);
	self.bAutoUpgrade = false;

	self:superCall("dispose");
end





--------------------------------------------------





Lua_MarryAttrsItem = class("Lua_MarryAttrsItem", Lua_ListCell);
function Lua_MarryAttrsItem:ctor(p)
	self:superCall("ctor", p, "MarryAttrsItem_skin");
end

function Lua_MarryAttrsItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_MarryAttrsItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.nameTxt.text = Lua_ThingDefine.getParamName(data.name).."：";

	local str;
	local isPer = false;
	if Lua_ThingDefine.isPercentParam(data.name) == true then
		isPer = true;
		str = (data.curValue / 100).."%";
	else
		str = data.curValue;
	end
	self.curValueTxt.text = str;

	local posX = self.nameTxt.mainContent.transform.localPosition.x + self.nameTxt.width;
	local posY = self.nameTxt.mainContent.transform.localPosition.y;
	self.curValueTxt:setLocation(posX, posY, 0);

	posX = self.curValueTxt.mainContent.transform.localPosition.x + self.curValueTxt.width + 50;
	posY = self.curValueTxt.mainContent.transform.localPosition.y;
	-- self.nextObj.transform.localPosition = Vector3(posX, posY, 0);
	LuaUtil.setObjPos(self.nextObj, posX, posY, 0);

	if data.nextValue == nil or data.nextValue == 0 then
		self.nextObj:SetActive(false);
	else
		self.nextObj:SetActive(true);
		if isPer == true then
			self.nextTxt.text = (data.nextValue / 100).."%";
		else
			self.nextTxt.text = data.nextValue;
		end
	end
end

function Lua_MarryAttrsItem:dispose()
	self.data = nil;

    self:superCall("dispose");
end





--------------------------------------------------





Lua_MarryKeepsakeCostItem = class("Lua_MarryKeepsakeCostItem", Lua_ListCell);
function Lua_MarryKeepsakeCostItem:buildShowItem()
	self:superCall("buildShowItem");

	self.toolImg = Lua_ToolImage.new(self.content);
	self.toolImg:setCanClick(false);
end

function Lua_MarryKeepsakeCostItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local num = DataCenter.packData:getBagType(Lua_PackData.BAG_PACK):getItemNum(data.id);
	self.toolImg.data = data;
    self.toolImg:showNumLimit(num, data.count, 2);
end

function Lua_MarryKeepsakeCostItem:onPlayerSoundClick(go)
	if self.data ~= nil then
		Lua_PackUtil.showItemInfo(self.data);
	end
end

function Lua_MarryKeepsakeCostItem:dispose()
	if self.toolImg ~= nil then
		self.toolImg:dispose();
		self.toolImg = nil;
	end

	self.data = nil;
	self:superCall("dispose");
end